==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LiteralFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { LiteralFilterExpressionDescription } from "./LiteralFilterExpressionDescription";
/**
 * @hidden
 */
var LiteralFilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LiteralFilterExpressionDescriptionMetadata, _super);
    function LiteralFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LiteralFilterExpressionDescriptionMetadata.b = function (a) {
        if (LiteralFilterExpressionDescriptionMetadata.a == null) {
            LiteralFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LiteralFilterExpressionDescriptionMetadata.c(LiteralFilterExpressionDescriptionMetadata.a);
        }
        if (a.g(LiteralFilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.s(LiteralFilterExpressionDescriptionMetadata.a);
    };
    LiteralFilterExpressionDescriptionMetadata.c = function (a) {
        FilterExpressionDescriptionMetadata.c(a);
        a.item("LiteralValue", "Unknown");
        a.item("LeaveUnquoted", "Boolean");
    };
    LiteralFilterExpressionDescriptionMetadata.d = function (a) {
        LiteralFilterExpressionDescriptionMetadata.b(a);
        a.u("LiteralFilterExpression", function () { return new LiteralFilterExpressionDescription(); });
        a.t("LiteralFilterExpression", LiteralFilterExpressionDescriptionMetadata.a);
    };
    LiteralFilterExpressionDescriptionMetadata.$t = markType(LiteralFilterExpressionDescriptionMetadata, 'LiteralFilterExpressionDescriptionMetadata');
    LiteralFilterExpressionDescriptionMetadata.a = null;
    return LiteralFilterExpressionDescriptionMetadata;
}(Base));
export { LiteralFilterExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LiteralFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { LiteralFilterExpressionDescription } from "./LiteralFilterExpressionDescription";
/**
 * @hidden
 */
var LiteralFilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LiteralFilterExpressionDescriptionMetadata, _super);
    function LiteralFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LiteralFilterExpressionDescriptionMetadata.b = function (a) {
        if (LiteralFilterExpressionDescriptionMetadata.a == null) {
            LiteralFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LiteralFilterExpressionDescriptionMetadata.c(LiteralFilterExpressionDescriptionMetadata.a);
        }
        if (a.j(LiteralFilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(LiteralFilterExpressionDescriptionMetadata.a);
    };
    LiteralFilterExpressionDescriptionMetadata.c = function (a) {
        FilterExpressionDescriptionMetadata.c(a);
        a.item("LiteralValue", "Unknown");
        a.item("LeaveUnquoted", "Boolean");
    };
    LiteralFilterExpressionDescriptionMetadata.d = function (a) {
        LiteralFilterExpressionDescriptionMetadata.b(a);
        a.aa("LiteralFilterExpression", function () { return new LiteralFilterExpressionDescription(); });
        a.z("LiteralFilterExpression", LiteralFilterExpressionDescriptionMetadata.a);
    };
    LiteralFilterExpressionDescriptionMetadata.$t = markType(LiteralFilterExpressionDescriptionMetadata, 'LiteralFilterExpressionDescriptionMetadata');
    LiteralFilterExpressionDescriptionMetadata.a = null;
    return LiteralFilterExpressionDescriptionMetadata;
}(Base));
export { LiteralFilterExpressionDescriptionMetadata };
